@@ -359,9 +359,11 @@ PRIVATE WarnOptionList
   {"pointer",		&f77_cray_pointers,
 				"Cray pointer syntax"},
   {"quad-constant",	&f77_quad_constants,
-				"quad precision constants like 1.23Q4"},
+				"Quad precision constants like 1.23Q4"},
   {"quotemark",		&f77_quotemarks,
 				"Strings delimited by \"quote marks\""},
+  {"statement-order",	&f77_stmt_order,
+				"Statement out of order"},
   {"typeless-constant",	&f77_typeless_constants,
 				"Typeless constants like Z'19AF"},
   {"type-size",		&f77_typesize,
@@ -501,7 +503,7 @@ PRIVATE StrsettingList strsetting[]={
 
 
 PRIVATE int must_open_outfile=FALSE; /* Flag set to TRUE when out=name given */
-PRIVATE int nocheck_given=FALSE; /* Keep track whether -nocheck was given */
+PRIVATE int checks_on=TRUE; /* Keep track whether -nocheck was given */
 
 PRIVATE char *dclfile;
 PRIVATE int actioncount=0;
@@ -564,11 +566,11 @@ main(argc,argv)
 		if(help_screen) goto do_action;
 
 				/* Allow checking to be turned off */
-		if(! do_check ) {
+		if( !do_check && checks_on ) {
 		  turn_off_checks();
-		  do_check = TRUE; /* close the trapdoor */
-		  nocheck_given = TRUE;	/* but remember it was done */
+		  checks_on = FALSE;	/* remember it was done */
 		}
+
 				/* Derive usage options from -usage setting */
 		var_usage_check = usage_check % 10;
 		com_usage_check = (usage_check/10) % 10;
@@ -1812,6 +1814,8 @@ PRIVATE void turn_off_checks(VOID)
 	    *(strsetting[i].strvalue) = strsetting[i].turnoff;
 	  }
 	}
+				/* Turn off checks without own options */
+	misc_warn = FALSE;
 
 /* Restore the ones that aren't for checks */
 	quiet=save_quiet;
@@ -1936,7 +1940,7 @@ wrapup(VOID)	/* look at cross references, etc. */
 				   turning on[off] bit 1 in ext_usage_check.
 				 */
 	if(ext_def_check) {
-	  if(nocheck_given)	/* -nocheck followed by -ext */
+	  if(!checks_on)	/* -nocheck followed by -ext */
 	    ext_usage_check |= 0x1;
 	}
 	else {
