@@ -16,7 +16,7 @@
 modify it and/or redistribute it, retaining this notice.\n\
 No guarantees accompany this software."
 #define VERSION_NUMBER		"FTNCHEK Version 2.9 April 1996"
-#define PATCHLEVEL		"Patch Level 3"
+#define PATCHLEVEL		"Patch Level 4"
 #define PROJECT_VERSION		"P2" /* Project file format version number */
 
 		/* Define macro PROTO for declaring function prototypes.  If
@@ -654,6 +654,7 @@ OPT(int,f77_param_intrinsic,F77_ALL);
 OPT(int,f77_param_noparen,F77_ALL);
 OPT(int,f77_quad_constants,F77_ALL);
 OPT(int,f77_quotemarks,F77_ALL);
+OPT(int,f77_stmt_order,F77_ALL);
 OPT(int,f77_typeless_constants,F77_ALL);
 OPT(int,f77_typesize,F77_ALL);
 OPT(int,f77_underscores,F77_ALL);
@@ -701,6 +702,10 @@ OPT(int,trunc_sigfigs,TRUNC_ALL);	/* Sngl const overspecified */
 
 		/* End of -truncation options */
 
+	/* The following flag is for warnings not covered by other flags,
+	   so that all warnings can be turned off by -nocheck. */
+OPT(int,misc_warn,TRUE);
+
 	/* The following variables are controlled by command line options */
 
 OPT(int,print_call_tree,FALSE);	/* Print the call tree */
