@@ -19,12 +19,12 @@ FILE=$3
 	if [ ! -f ${OKAY}/${FILE} ] ;
 	then
 	    echo "${FILE} is new" ;
-	    cp ${FILE} ${OKAY}/${FILE} ;
+	    /bin/cp ${FILE} ${OKAY}/${FILE} ;
 	fi
-	if cmp ${OKAY}/${FILE} ${FILE} ;
+	if /usr/bin/cmp ${OKAY}/${FILE} ${FILE} ;
 	then
 	    /bin/rm -f ${FILE} ;
-	    echo '.' | awk '{printf("%s",$1);}' ;
+	    echo '.' | gawk '{printf("%s",$1);}' ;
 	else
 	    touch CHECK_FAILED
 	    echo "--------------------------------------------------" ;
@@ -35,6 +35,6 @@ FILE=$3
 		mkdir ${VARY} ;
 	    fi
 	    /bin/mv ${FILE} ${VARY}/${FILE} ;
-	    diff ${OKAY}/${FILE} ${VARY}/${FILE} ;
+	    /usr/bin/diff ${OKAY}/${FILE} ${VARY}/${FILE} ;
 	fi
 	exit 0
